@@ -813,9 +813,9 @@ class SliderWidget(HLayoutMixin, LineEditWidget):
         if item.get_prop_value("display", "slider"):
             self.vmin = item.get_prop_value("data", "min")
             self.vmax = item.get_prop_value("data", "max")
-            assert (
-                self.vmin is not None and self.vmax is not None
-            ), "SliderWidget requires that item min/max have been defined"
+            assert self.vmin is not None and self.vmax is not None, (
+                "SliderWidget requires that item min/max have been defined"
+            )
             self.slider = QSlider()
             self.slider.setOrientation(Qt.Horizontal)  # type:ignore
             self.setup_slider(item)
@@ -1150,7 +1150,7 @@ class MultipleChoiceWidget(AbstractDataSetWidget):
         _choices = item.get_prop_value("data", "choices")
         for _k, choice, _img in _choices:
             checkbox = QCheckBox(choice)
-            checkbox.stateChanged.connect(lambda: self.notify_value_change())
+            checkbox.stateChanged.connect(lambda: self.checkbox_clicked())
             layout.addWidget(checkbox, cx, cy)
             if nx < 0:
                 cy += 1
@@ -1214,6 +1214,11 @@ class MultipleChoiceWidget(AbstractDataSetWidget):
         super().set_state()
         self.groupbox.setEnabled(not self.is_readonly())
 
+    def checkbox_clicked(self):
+        """Update the data item value when a checkbox is clicked"""
+        self.notify_value_change()
+        _display_callback(self, self.value())
+
 
 class FloatArrayWidget(AbstractDataSetWidget):
     """
@@ -1309,7 +1314,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
                 maxt = ", ".join(
                     [format % real_arr[:, r].max() for r in range(arr.shape[1])]
                 )
-        except (TypeError, IndexError):
+        except (TypeError, IndexError, ValueError):
             mint, maxt = "-", "-"
         self.min_label.setText(mint)
         self.max_label.setText(maxt)
